@@ -1,7 +1,8 @@
-from sanic.response import json
+from typing import Any
+
 from sanic.views import HTTPMethodView
 
-from insanic.http import HTTP_STATUS, Response
+from insanic.http import HTTP_STATUS, Response, response_json
 from insanic.serializers import Serializer
 
 __all__ = (
@@ -10,19 +11,17 @@ __all__ = (
 
 
 class View(HTTPMethodView):
-    Response = Response  # Shortcut for typing
+    serializer_class: type[Serializer] | None = None
 
-    serializer_class: Serializer | None = None
-
-    def ok_response(self, data: dict, http_status=HTTP_STATUS.OK) -> Response:
+    def ok_response(self, data: dict, http_status: int = HTTP_STATUS.OK) -> Response:  # pylint: disable=no-self-use
         response_data = { 'status': 'ok', 'data': data }
-        return json(response_data, status=http_status)
+        return response_json(response_data, status=http_status)
 
-    def error_response(self, errors: dict, http_status=HTTP_STATUS.BAD_REQUEST) -> Response:
+    def error_response(self, errors: dict, http_status : int = HTTP_STATUS.BAD_REQUEST) -> Response:  # pylint: disable=no-self-use
         response_data = { 'status': 'error', 'errors': errors }
-        return json(response_data, status=http_status)
+        return response_json(response_data, status=http_status)
 
-    async def serialized_response(self, data: any, serializer_class: Serializer=None, http_status=HTTP_STATUS.OK) -> Response:
+    async def serialized_response(self, data: Any, serializer_class: type[Serializer] | None = None, http_status: int = HTTP_STATUS.OK) -> Response :  # pylint: disable=line-too-long
         serializer_class = serializer_class or self.serializer_class
         if not serializer_class:
             raise NotImplementedError('Serializer class must be specified')
